summaryrefslogtreecommitdiffstats
path: root/klettres/klettres/klettres.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:12:18 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:12:18 -0600
commitee52bb567f32fefdcf06e083c76562ea40ccf174 (patch)
tree8926667faaed3a18bec210ec14ffb9392ea8930d /klettres/klettres/klettres.h
parent088cc453ec425bf86d610880d09645ea166a14fa (diff)
downloadtdeedu-ee52bb567f32fefdcf06e083c76562ea40ccf174.tar.gz
tdeedu-ee52bb567f32fefdcf06e083c76562ea40ccf174.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'klettres/klettres/klettres.h')
-rw-r--r--klettres/klettres/klettres.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/klettres/klettres/klettres.h b/klettres/klettres/klettres.h
index e717433f..02ff5197 100644
--- a/klettres/klettres/klettres.h
+++ b/klettres/klettres/klettres.h
@@ -32,10 +32,10 @@
#include "soundfactory.h"
class TQLabel;
-class KToggleAction;
-class KSelectAction;
+class TDEToggleAction;
+class TDESelectAction;
class KComboBox;
-class KToolBar;
+class TDEToolBar;
class KLNewStuff;
/**
@@ -43,7 +43,7 @@ class KLNewStuff;
* @author Anne-Marie Mahfouf <annemarie.mahfouf@free.fr>
* @version 1.4
*/
-class KLettres : public KMainWindow
+class KLettres : public TDEMainWindow
{
Q_OBJECT
@@ -69,7 +69,7 @@ public:
///Number corresponding to the selected language: 0 is Czech, 1 is Danish, 2 is English (default), 3 is French, 4 is Dutch, 5 is Slovak
//uint selectedLanguage;
///Action that sets up the Language menu
- KSelectAction *m_languageAction;
+ TDESelectAction *m_languageAction;
///Look for all languages available
void findLanguages();
@@ -81,15 +81,15 @@ protected:
///Call an instance of the KLettresView widget
KLettresView *m_view;
///Action that enables the ShowMenuBar item in the Settings menu
- KToggleAction *m_menubarAction;
+ TDEToggleAction *m_menubarAction;
///Action that sets up the Level menu
- KSelectAction *m_levelAction;
+ TDESelectAction *m_levelAction;
///Action that sets up the Look menu
- KSelectAction *m_themeAction;
+ TDESelectAction *m_themeAction;
///Action allow the Kid mode
- KToggleAction *m_kidAction;
+ TDEToggleAction *m_kidAction;
///Action allow the Grownup mode
- KToggleAction *m_grownupAction;
+ TDEToggleAction *m_grownupAction;
///Label stating the language in the statusbar
TQLabel *m_langLabel;
///Label stating the level in the statusbar
@@ -98,10 +98,10 @@ protected:
TQStringList m_levelsNames;
///Holds the looks
TQStringList m_themesNames;
- ///Create an instance of a KToolBar
- KToolBar *m_mainToolbar;
+ ///Create an instance of a TDEToolBar
+ TDEToolBar *m_mainToolbar;
///Second toolbar with buttons of special characters per language
- KToolBar *m_secondToolbar;
+ TDEToolBar *m_secondToolbar;
///is false when menubar button is not shown
bool menuBool;
///Build the main window menus